@@ -8,11 +8,11 @@ master_doc = 'index'
 project = u'Sphinx theme for dynamic html presentation style'
 copyright = u'2012, Sphinx-users.jp'
 
-version = '0.1.2'
+version = '0.1.3'
 
 # -- Options for HTML output -----------------------------------
 
-extensions = ['sphinxjp.themecore',
+extensions = ['sphinxjp.themes.impressjs',
               'sphinxcontrib.blockdiag',
               'sphinxcontrib.seqdiag']
 html_theme = 'impressjs'
