@@ -12,6 +12,6 @@ def get_path():
     return template_path
 
 
-def setup_directives(app):
+def setup(app):
     """entry-point for sphinxjp.themecore directives."""
     directives.setup(app)
